# Politique de publication

## Gestion des versions

- Balises stables : `vX.Y.Z`
- Balises de pré-version : `vX.Y.Z-rc.N`

## Pipeline de publication

1. Porte de qualité
2. Construisez des artefacts
3. Publier PyPI
4. Créer une version GitHub
5. Publier des documents en push sur `main`

## Journal des modifications

Généré à partir de commits conventionnels et de notes de version organisées.